@@ -1,12 +1,12 @@
 # Ogg Theora support.
 #
-# Copyright 2006 Joe Wreschnig <piman@sacredchao.net>
+# Copyright 2006 Joe Wreschnig
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
 # published by the Free Software Foundation.
 #
-# $Id: oggtheora.py 4275 2008-06-01 06:32:37Z piman $
+# $Id: oggtheora.py 3976 2007-01-13 22:00:14Z piman $
 
 """Read and write Ogg Theora comments.
 
@@ -50,7 +50,7 @@ class OggTheoraInfo(object):
                 "found Theora version %d.%d != 3.2" % (vmaj, vmin))
         fps_num, fps_den = struct.unpack(">2I", data[22:30])
         self.fps = fps_num / float(fps_den)
-        self.bitrate, = struct.unpack(">I", data[37:40] + "\x00")
+        self.bitrate = struct.unpack(">I", data[37:40] + "\x00")[0]
         self.serial = page.serial
 
     def pprint(self):
