@@ -7,11 +7,11 @@ from mutagen.oggvorbis import OggVorbis
 from mutagen.oggflac import OggFLAC
 from mutagen.oggspeex import OggSpeex
 from mutagen.oggtheora import OggTheora
-from mutagen.mp3 import MP3
+from mutagen.mp3 import MP3, EasyMP3
 from mutagen.apev2 import APEv2File
 from mutagen.flac import FLAC
 from mutagen.wavpack import WavPack
-from mutagen.trueaudio import TrueAudio
+from mutagen.trueaudio import TrueAudio, EasyTrueAudio
 from mutagen.mp4 import MP4
 from mutagen.musepack import Musepack
 from mutagen.monkeysaudio import MonkeysAudio
@@ -29,6 +29,10 @@ class TMetadata(TestCase):
     def test_virtual_constructor(self):
         self.failUnlessRaises(NotImplementedError, Metadata, "filename")
 
+    def test_load(self):
+        m = Metadata()
+        self.failUnlessRaises(NotImplementedError, m.load, "filename")
+
     def test_virtual_save(self):
         self.failUnlessRaises(NotImplementedError, self.FakeMeta().save)
         self.failUnlessRaises(
@@ -49,6 +53,9 @@ class TFileType(TestCase):
     def test_delitem_not_there(self):
         self.failUnlessRaises(KeyError, self.vorbis.__delitem__, "foobar")
 
+    def test_add_tags(self):
+        self.failUnlessRaises(NotImplementedError, FileType().add_tags)
+
     def test_delitem(self):
         self.vorbis["foobar"] = "quux"
         del(self.vorbis["foobar"])
@@ -102,6 +109,11 @@ class TFile(TestCase):
         self.failUnless(isinstance(
             File(os.path.join("tests", "data", "silence-44-s.mp3")), MP3))
 
+    def test_easy_mp3(self):
+        self.failUnless(isinstance(
+            File(os.path.join("tests", "data", "silence-44-s.mp3"), easy=True),
+            EasyMP3))
+
     def test_flac(self):
         self.failUnless(isinstance(
             File(os.path.join("tests", "data", "silence-44-s.flac")), FLAC))
@@ -128,6 +140,11 @@ class TFile(TestCase):
         self.failUnless(isinstance(
             File(os.path.join("tests", "data", "empty.tta")), TrueAudio))
 
+    def test_easy_tta(self):
+        self.failUnless(isinstance(
+            File(os.path.join("tests", "data", "empty.tta"), easy=True),
+            EasyTrueAudio))
+
     def test_wavpack(self):
         self.failUnless(isinstance(
             File(os.path.join("tests", "data", "silence-44-s.wv")), WavPack))
@@ -171,7 +188,7 @@ class TMutagen(TestCase):
     def test_not_prerelease(self):
         from mutagen import version
         from os.path import dirname, basename, abspath
-        trunk = dirname(dirname(dirname(abspath(__file__))))
+        trunk = dirname(dirname(abspath(__file__)))
         definitely_trunk = os.path.join(trunk, "..", "trunk")
         if os.path.isdir(definitely_trunk):
             if basename(trunk) != "trunk":
