@@ -387,6 +387,9 @@ class TFLAC(TestCase):
     def test_mime(self):
         self.failUnless("audio/x-flac" in self.flac.mime)
 
+    def test_variable_block_size(self):
+        FLAC(os.path.join("tests", "data", "variable-block.flac"))
+
     def tearDown(self):
         os.unlink(self.NEW)
 
