@@ -2,7 +2,7 @@ import os; from os.path import join
 import shutil
 from unittest import TestCase
 from tests import add
-from mutagen.id3 import ID3, BitPaddedInt, COMR, Frames, Frames_2_2, ID3Warning
+from mutagen.id3 import ID3, BitPaddedInt, COMR, Frames, Frames_2_2, ID3Warning, ID3JunkFrameError
 from StringIO import StringIO
 import warnings
 warnings.simplefilter('error', ID3Warning)
@@ -102,10 +102,17 @@ class ID3Loading(TestCase):
         id3._ID3__fileobj = StringIO('ID3\x04\x00\x1f\x00\x00\x00\x00')
         self.assertRaises(ValueError, id3._ID3__load_header)
 
+    def test_header_2_4_allow_footer(self):
+        id3 = ID3()
+        id3._ID3__fileobj = StringIO('ID3\x04\x00\x10\x00\x00\x00\x00')
+        id3._ID3__load_header()
+
     def test_header_2_3_invalid_flags(self):
         id3 = ID3()
         id3._ID3__fileobj = StringIO('ID3\x03\x00\x1f\x00\x00\x00\x00')
         self.assertRaises(ValueError, id3._ID3__load_header)
+        id3._ID3__fileobj = StringIO('ID3\x03\x00\x0f\x00\x00\x00\x00')
+        self.assertRaises(ValueError, id3._ID3__load_header)
 
     def test_header_2_2(self):
         id3 = ID3()
@@ -131,6 +138,20 @@ class ID3Loading(TestCase):
         self.assertEquals(id3._ID3__extsize, 1)
         self.assertEquals(id3._ID3__extdata, '\x5a')
 
+    def test_header_2_4_extended_but_not(self):
+        id3 = ID3()
+        id3._ID3__fileobj = StringIO(
+            'ID3\x04\x00\x40\x00\x00\x00\x00TIT1\x00\x00\x00\x01a')
+        id3._ID3__load_header()
+        self.assertEquals(id3._ID3__extsize, 0)
+        self.assertEquals(id3._ID3__extdata, '')
+
+    def test_header_2_4_extended_but_not_but_not_tag(self):
+        id3 = ID3()
+        id3._ID3__fileobj = StringIO(
+            'ID3\x04\x00\x40\x00\x00\x00\x00TIT9')
+        self.failUnlessRaises(EOFError, id3._ID3__load_header)
+
     def test_header_2_3_extended(self):
         id3 = ID3()
         id3._ID3__fileobj = StringIO(
@@ -159,6 +180,26 @@ class ID3Loading(TestCase):
         self.assertRaises(ValueError, id3._ID3__fullread, -3)
         self.assertRaises(EOFError, id3._ID3__fullread, 3)
 
+class Issue21(TestCase):
+    uses_mmap = False
+
+    # Files with bad extended header flags failed to read tags.
+    # Ensure the extended header is turned off, and the frames are
+    # read.
+    def setUp(self):
+        self.id3 = ID3(join('tests', 'data', 'issue_21.id3'))
+
+    def test_no_ext(self):
+        self.failIf(self.id3.f_extended)
+
+    def test_has_tags(self):
+        self.failUnless("TIT2" in self.id3)
+        self.failUnless("TALB" in self.id3)
+
+    def test_tit2_value(self):
+        self.failUnlessEqual(self.id3["TIT2"].text, [u"Punk To Funk"])
+add(Issue21)
+
 class ID3Tags(TestCase):
     uses_mmap = False
 
@@ -231,6 +272,11 @@ class ID3Tags(TestCase):
     def test_junkframe(self):
         self.assertRaises(ValueError, Frames["TPE1"].fromData, _24, 0, "")
 
+    def test_bad_sylt(self):
+        self.assertRaises(
+            ID3JunkFrameError, Frames["SYLT"].fromData, _24, 0x0,
+            "\x00eng\x01description\x00foobar")
+
     def test_extradata(self):
         from mutagen.id3 import RVRB, RBUF
         self.assertRaises(ID3Warning,
@@ -307,6 +353,15 @@ class ID3v1Tags(TestCase):
         self.assertEquals(
             MakeID3v1({'COMM': COMM(encoding=0, text="")}), empty)
 
+    def test_make_v1_from_tyer(self):
+        from mutagen.id3 import ParseID3v1, MakeID3v1, TYER, TDRC
+        self.assertEquals(
+            MakeID3v1({"TDRC": TDRC(text="2010-10-10")}),
+            MakeID3v1({"TYER": TYER(text="2010")}))
+        self.assertEquals(
+            ParseID3v1(MakeID3v1({"TDRC": TDRC(text="2010-10-10")})),
+            ParseID3v1(MakeID3v1({"TYER": TYER(text="2010")})))
+
     def test_invalid(self):
         from mutagen.id3 import ParseID3v1
         self.failUnless(ParseID3v1("") is None)
@@ -352,10 +407,6 @@ class TestWriteID3v1(TestCase):
         self.audio.save(v1=2)
         self.failUnlessV1()
 
-    def test_save_add(self):
-        self.audio.save(v1=2)
-        self.failUnlessV1()
-
     def test_save_defaults(self):
         self.audio.save(v1=0)
         self.failIfV1()
@@ -437,6 +488,8 @@ def TestReadTags():
     ['TSOA', '\x00ab', 'ab', '', dict(encoding=0)],
     ['TSOP', '\x00ab', 'ab', '', dict(encoding=0)],
     ['TSOT', '\x00ab', 'ab', '', dict(encoding=0)],
+    ['TSO2', '\x00ab', 'ab', '', dict(encoding=0)],
+    ['TSOC', '\x00ab', 'ab', '', dict(encoding=0)],
     ['TSRC', '\x0012345', '12345', '', dict(encoding=0)],
     ['TSSE', '\x0012345', '12345', '', dict(encoding=0)],
     ['TSST', '\x0012345', '12345', '', dict(encoding=0)],
@@ -488,6 +541,11 @@ def TestReadTags():
     ['PCNT', '\x00\x00\x00\x11', 17, 17, dict(count=17)],
     ['POPM', 'foo@bar.org\x00\xde\x00\x00\x00\x11', 222, 222,
         dict(email="foo@bar.org", rating=222, count=17)],
+    ['POPM', 'foo@bar.org\x00\xde\x00', 222, 222,
+        dict(email="foo@bar.org", rating=222, count=0)],
+    # Issue #33 - POPM may have no playcount at all.
+    ['POPM', 'foo@bar.org\x00\xde', 222, 222,
+        dict(email="foo@bar.org", rating=222)],
 
     ['UFID', 'own\x00data', 'data', '', dict(data='data', owner='own')],
     ['UFID', 'own\x00\xdd', '\xdd', '', dict(data='\xdd', owner='own')],
@@ -1630,6 +1688,15 @@ class BadPOPM(TestCase):
         self.assertEquals(popm.rating, 125)
         self.assertEquals(popm.count, 2**32+1)
 
+class TimeStampTextFrame(TestCase):
+    uses_mmap = False
+
+    from mutagen.id3 import TimeStampTextFrame as Frame
+
+    def test_compare_to_unicode(self):
+        frame = self.Frame(encoding=0, text=[u'1987', u'1988'])
+        self.failUnlessEqual(frame, unicode(frame))
+
 add(ID3Loading)
 add(ID3GetSetDel)
 add(BitPaddedIntTest)
@@ -1647,6 +1714,7 @@ add(NoHash)
 add(FrameIDValidate)
 add(BadTYER)
 add(BadPOPM)
+add(TimeStampTextFrame)
 
 try: import eyeD3
 except ImportError: pass
